/* ~Օʉ
 * Copyright (C) 2004 Kagetani Hideto
 */
#ifndef __IMAGE_H__
#define __IMAGE_H__

#include <stdio.h>
#include "aspi.h"

typedef struct {
	FILE *fp;
	char *filename;
	int fileindex;
	DWORD bytecount;
} IMAGEFILE;

extern int InitializeImage(IMAGEFILE *image);
extern void FreeImage(IMAGEFILE *image);
extern int OpenImage(IMAGEFILE *image, const char *filename, BOOL reader);
extern int ReadImageFile(IMAGEFILE *image, void *buf, DWORD size, BOOL split);
extern int WriteImageFile(IMAGEFILE *image, void *buf, DWORD size, BOOL split);
extern void RemoveImageFile(const char *basefilename);

#endif /* !__IMAGE_H__ */
